@@ -438,6 +438,7 @@ from .lazyexpr import (
     lazyudf,
     lazyexpr,
     LazyArray,
+    LazyUDF,
     _open_lazyarray,
     get_expr_operands,
     validate_expr,
@@ -450,6 +451,7 @@ from .proxy import Proxy, ProxySource, ProxyNDSource, ProxyNDField, SimpleProxy,
 from .schunk import SChunk, open
 from . import linalg
 from .linalg import tensordot, vecdot, permute_dims, matrix_transpose, matmul, transpose, diagonal, outer
+from .utils import linalg_funcs as linalg_funcs_list
 from . import fft
 
 # Registry for postfilters
@@ -500,6 +502,8 @@ from .ndarray import (
     arctan,
     arctan2,
     arctanh,
+    argmax,
+    argmin,
     array_from_ffi_ptr,
     asin,
     asinh,
@@ -610,6 +614,7 @@ __all__ = [  # noqa : RUF022
     "Filter",
     "LazyArray",
     "LazyExpr",
+    "LazyUDF",
     "NDArray",
     "NDField",
     "Operand",
@@ -627,6 +632,8 @@ __all__ = [  # noqa : RUF022
     "URLPath",
     # Version
     "__version__",
+    # Utils
+    "linalg_funcs_list",
     # Functions
     "abs",
     "acos",
@@ -644,6 +651,8 @@ __all__ = [  # noqa : RUF022
     "arctanh",
     "are_partitions_aligned",
     "are_partitions_behaved",
+    "argmax",
+    "argmin",
     "array_from_ffi_ptr",
     "asarray",
     "asin",
